@@ -7,23 +7,6 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-#    Copyright (c) 2007-2011 Dominique Dumont.
-#
-#    This file is part of Config-Model-Itself.
-#
-#    Config-Model-Itself is free software; you can redistribute it
-#    and/or modify it under the terms of the GNU Lesser Public License
-#    as published by the Free Software Foundation; either version 2.1
-#    of the License, or (at your option) any later version.
-#
-#    Config-Model-Itself is distributed in the hope that it will be
-#    useful, but WITHOUT ANY WARRANTY; without even the implied
-#    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-#    See the GNU Lesser Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser Public License
-#    along with Config-Model-Itself; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 [
   [
@@ -51,7 +34,7 @@
        => {
 	   type => 'hash',
 	   index_type => 'string' ,
-	   cargo => { type => 'leaf', value_type => 'uniline' } ,
+	   cargo => { type => 'leaf', value_type => 'string' } ,
 	   description => 'Sometime, using the value of a tree leaf is not enough and you need to substitute a replacement for any value you can get. This replacement can be done using a hash like notation within the formula using the %replace hash. Example $replace{$who} , where "who => \'- who_elt\' ',
 	  },
 
